/*
 * This file is part of Siril, an astronomy image processor.
 * Copyright (C) 2005-2011 Francois Meyer (dulle at free.fr)
 * Copyright (C) 2012-2021 team free-astro (see more in AUTHORS file)
 * Reference site is https://free-astro.org/index.php/Siril
 *
 * Siril is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Siril is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Siril. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef SRC_GUI_DIALOG_PREVIEW_H_
#define SRC_GUI_DIALOG_PREVIEW_H_

typedef struct _fileChooserPreview fileChooserPreview;

void siril_file_chooser_add_preview(GtkFileChooser *dialog, fileChooserPreview *preview);
void siril_preview_free(fileChooserPreview *preview);

#endif /* SRC_GUI_DIALOG_PREVIEW_H_ */
